/****************************************************************************
** Meta object code from reading C++ file 'generalsettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../nextcloud-client/src/gui/generalsettings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'generalsettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3OCC15GeneralSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto OCC::GeneralSettings::qt_create_metaobjectdata<qt_meta_tag_ZN3OCC15GeneralSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OCC::GeneralSettings",
        "slotStyleChanged",
        "",
        "saveMiscSettings",
        "slotToggleLaunchOnStartup",
        "slotToggleOptionalServerNotifications",
        "slotToggleChatNotifications",
        "slotToggleCallNotifications",
        "slotToggleQuotaWarningNotifications",
        "slotShowInExplorerNavigationPane",
        "slotIgnoreFilesEditor",
        "slotCreateDebugArchive",
        "loadMiscSettings",
        "slotShowLegalNotice",
        "slotRemotePollIntervalChanged",
        "seconds",
        "updatePollIntervalVisibility"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotStyleChanged'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveMiscSettings'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotToggleLaunchOnStartup'
        QtMocHelpers::SlotData<void(bool)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotToggleOptionalServerNotifications'
        QtMocHelpers::SlotData<void(bool)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotToggleChatNotifications'
        QtMocHelpers::SlotData<void(bool)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotToggleCallNotifications'
        QtMocHelpers::SlotData<void(bool)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotToggleQuotaWarningNotifications'
        QtMocHelpers::SlotData<void(bool)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotShowInExplorerNavigationPane'
        QtMocHelpers::SlotData<void(bool)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotIgnoreFilesEditor'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCreateDebugArchive'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'loadMiscSettings'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowLegalNotice'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRemotePollIntervalChanged'
        QtMocHelpers::SlotData<void(int)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'updatePollIntervalVisibility'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GeneralSettings, qt_meta_tag_ZN3OCC15GeneralSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OCC::GeneralSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3OCC15GeneralSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3OCC15GeneralSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3OCC15GeneralSettingsE_t>.metaTypes,
    nullptr
} };

void OCC::GeneralSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GeneralSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotStyleChanged(); break;
        case 1: _t->saveMiscSettings(); break;
        case 2: _t->slotToggleLaunchOnStartup((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->slotToggleOptionalServerNotifications((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->slotToggleChatNotifications((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->slotToggleCallNotifications((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->slotToggleQuotaWarningNotifications((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->slotShowInExplorerNavigationPane((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->slotIgnoreFilesEditor(); break;
        case 9: _t->slotCreateDebugArchive(); break;
        case 10: _t->loadMiscSettings(); break;
        case 11: _t->slotShowLegalNotice(); break;
        case 12: _t->slotRemotePollIntervalChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->updatePollIntervalVisibility(); break;
        default: ;
        }
    }
}

const QMetaObject *OCC::GeneralSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OCC::GeneralSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3OCC15GeneralSettingsE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int OCC::GeneralSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    return _id;
}
QT_WARNING_POP
