/****************************************************************************
** Meta object code from reading C++ file 'httpcredentials.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../nextcloud-client/src/libsync/creds/httpcredentials.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'httpcredentials.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3OCC15HttpCredentialsE_t {};
} // unnamed namespace

template <> constexpr inline auto OCC::HttpCredentials::qt_create_metaobjectdata<qt_meta_tag_ZN3OCC15HttpCredentialsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OCC::HttpCredentials",
        "slotAuthentication",
        "",
        "QNetworkReply*",
        "QAuthenticator*",
        "slotReadClientCertPasswordJobDone",
        "QKeychain::Job*",
        "slotReadClientCertPEMJobDone",
        "slotReadClientKeyPEMJobDone",
        "slotReadPasswordFromKeychain",
        "slotReadJobDone",
        "slotWriteClientCertPasswordJobDone",
        "slotWriteClientCertPEMJobDone",
        "slotWriteClientKeyPEMJobDone",
        "slotWritePasswordToKeychain",
        "slotWriteJobDone"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotAuthentication'
        QtMocHelpers::SlotData<void(QNetworkReply *, QAuthenticator *)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 4, 2 },
        }}),
        // Slot 'slotReadClientCertPasswordJobDone'
        QtMocHelpers::SlotData<void(QKeychain::Job *)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Slot 'slotReadClientCertPEMJobDone'
        QtMocHelpers::SlotData<void(QKeychain::Job *)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Slot 'slotReadClientKeyPEMJobDone'
        QtMocHelpers::SlotData<void(QKeychain::Job *)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Slot 'slotReadPasswordFromKeychain'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotReadJobDone'
        QtMocHelpers::SlotData<void(QKeychain::Job *)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Slot 'slotWriteClientCertPasswordJobDone'
        QtMocHelpers::SlotData<void(QKeychain::Job *)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Slot 'slotWriteClientCertPEMJobDone'
        QtMocHelpers::SlotData<void(QKeychain::Job *)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Slot 'slotWriteClientKeyPEMJobDone'
        QtMocHelpers::SlotData<void(QKeychain::Job *)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Slot 'slotWritePasswordToKeychain'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotWriteJobDone'
        QtMocHelpers::SlotData<void(QKeychain::Job *)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<HttpCredentials, qt_meta_tag_ZN3OCC15HttpCredentialsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OCC::HttpCredentials::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractCredentials::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3OCC15HttpCredentialsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3OCC15HttpCredentialsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3OCC15HttpCredentialsE_t>.metaTypes,
    nullptr
} };

void OCC::HttpCredentials::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<HttpCredentials *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotAuthentication((*reinterpret_cast<std::add_pointer_t<QNetworkReply*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAuthenticator*>>(_a[2]))); break;
        case 1: _t->slotReadClientCertPasswordJobDone((*reinterpret_cast<std::add_pointer_t<QKeychain::Job*>>(_a[1]))); break;
        case 2: _t->slotReadClientCertPEMJobDone((*reinterpret_cast<std::add_pointer_t<QKeychain::Job*>>(_a[1]))); break;
        case 3: _t->slotReadClientKeyPEMJobDone((*reinterpret_cast<std::add_pointer_t<QKeychain::Job*>>(_a[1]))); break;
        case 4: _t->slotReadPasswordFromKeychain(); break;
        case 5: _t->slotReadJobDone((*reinterpret_cast<std::add_pointer_t<QKeychain::Job*>>(_a[1]))); break;
        case 6: _t->slotWriteClientCertPasswordJobDone((*reinterpret_cast<std::add_pointer_t<QKeychain::Job*>>(_a[1]))); break;
        case 7: _t->slotWriteClientCertPEMJobDone((*reinterpret_cast<std::add_pointer_t<QKeychain::Job*>>(_a[1]))); break;
        case 8: _t->slotWriteClientKeyPEMJobDone((*reinterpret_cast<std::add_pointer_t<QKeychain::Job*>>(_a[1]))); break;
        case 9: _t->slotWritePasswordToKeychain(); break;
        case 10: _t->slotWriteJobDone((*reinterpret_cast<std::add_pointer_t<QKeychain::Job*>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *OCC::HttpCredentials::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OCC::HttpCredentials::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3OCC15HttpCredentialsE_t>.strings))
        return static_cast<void*>(this);
    return AbstractCredentials::qt_metacast(_clname);
}

int OCC::HttpCredentials::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractCredentials::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}
QT_WARNING_POP
